@media screen and (max-width:1300px) {
    .container {
        width: 800px;
        margin: auto;
        padding: 40px 10px 15px 10px;
    }

    .main{
        min-height: 500px;
    }
    .main h1{
        font-size: 70px;
    }

    .main hr{
        margin-top: 100px;
    }

    .main .stats{
        top: 300px;
        right: 7%;
    }


    .form input[type=text], .form input[type=email]{
    width: 300px;
    }

    .form .social{
        width: 30%;
    }

    footer{
        width: 95%;
        padding: 40px 3% 15px 3%;
    }
}

@media screen and (max-width:800px) {
    .container {
        width: 500px;
        margin: auto;
        padding: 40px 10px 15px 10px;
    }

    .main{
        min-height: 650px;
    }

    .main .stats{
        position: static;
    }

    .appel .container > div{
        flex-direction: column;
    }

    .form form{
        text-align: center;
    }

    .form form > div{
        justify-content: center;
    }

    .form .social{
        display: none;
    }
}

@media screen and (max-width:600px) {
    .container {
        width: 300px;
        margin: auto;
        padding: 20px 2px 10px 2px;
    }

    .main{
        min-height: 500px;
    }

    .main h1{
        font-size: 50px;
    }

    .main hr{
        display: none;
    }

    .main .stats{
        min-width: auto;
        margin-top: 25px;
        padding: 0;
    }

    .main .stats #stats{
        font-size: 60px;
    }

    .f-section a{
        width: 150px;
    }

    .form input[type=submit]{
        font-size: 20px;
    }

}